<?php

namespace Drupal\edit_media_modal\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\editor\EditorInterface;
use Drupal\media_library\MediaLibraryUiBuilder;
use Drupal\media\Form\EditorMediaDialog as CoreEditorMediaDialog;

/**
 * Overriding and improve EditorMediaDialog.
 */
class EditorMediaDialog extends CoreEditorMediaDialog {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, EditorInterface $editor = NULL) {
    $form = parent::buildForm($form, $form_state, $editor);

    if (isset($form_state->getUserInput()['editor_object'])) {
      $editor_object = $form_state->getUserInput()['editor_object'];
      $media_embed_element = $editor_object['attributes'];
    }
    else {
      $media_embed_element = $form_state->get('media_embed_element');
    }

    $media = $this->entityRepository->loadEntityByUuid('media', $media_embed_element['data-entity-uuid']);

    if ($media->access('update')) {
      $dialog_options = MediaLibraryUiBuilder::dialogOptions();
      $form['actions']['edit_media_link'] = $media->toLink($this->t('Edit this media'), 'edit-form', [
        'query' => [
          'edit_media_in_modal' => TRUE,
        ],
      ])->toRenderable();

      $form['actions']['edit_media_link']['#attributes'] = [
        'class' => [
          'js-media-library-edit-modal-link',
          'media-library-edit__modal-link',
          'use-ajax',
          'button',
        ],
        'target' => '_self',
        'data-dialog-options' => json_encode([
          'height' => $dialog_options['height'],
          'width' => $dialog_options['width'],
          'classes' => [
            'ui-dialog-content' => 'media-library-edit__modal-link',
          ],
        ]),
        'data-dialog-type' => 'modal',
      ];
    }

    return $form;
  }

}
